"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var spawn = require('child_process').spawn;
var kill = require('tree-kill');
var ProcessPluginClass = (function () {
    function ProcessPluginClass(opts) {
        this.processList = {};
        this.opts = opts;
    }
    ;
    ProcessPluginClass.prototype.start = function () {
        var _this = this;
        this.opts.process.forEach(function (detail) {
            _this.startProcess(detail);
        });
    };
    ProcessPluginClass.prototype.stop = function () {
        for (var key in this.processList) {
            kill(this.processList[key].instance.pid);
            logProcess('Killed', this.processList[key].detail, this.processList[key].instance);
            delete this.processList[key];
        }
    };
    ProcessPluginClass.prototype.postBundle = function (context) {
        this.stop();
        this.start();
    };
    ProcessPluginClass.prototype.startProcess = function (detail) {
        var _this = this;
        logDetail('Starting', detail);
        var instance = this.createProcess(detail);
        instance.on('close', function (code, signal) {
            logProcess('Finished', detail, instance);
            delete _this.processList[detail.processKey];
        });
        this.processList[detail.processKey] = {
            instance: instance,
            detail: detail,
        };
        if (detail.child) {
            this.processList[detail.processKey].instance.on('exit', function (code, signal) {
                console.log("Parent \"" + detail.processKey + "\" is finished. Starting \"" + detail.child.processKey + "\"");
                _this.startProcess(detail.child);
            });
        }
    };
    ProcessPluginClass.prototype.createProcess = function (detail) {
        var instance = spawnProcess(detail.processName, detail.processArgs, detail.verbose);
        return instance;
    };
    return ProcessPluginClass;
}());
exports.ProcessPluginClass = ProcessPluginClass;
function ProcessPlugin(options) {
    return new ProcessPluginClass(options);
}
exports.ProcessPlugin = ProcessPlugin;
;
function spawnProcess(processName, processArgs, verbose) {
    if (verbose) {
        return spawn(processName, processArgs, { stdio: 'inherit' });
    }
    return spawn(processName, processArgs);
}
function logProcess(action, detail, instance) {
    console.log(action + " \"" + detail.processKey + "\" (pid : " + instance.pid + ")");
}
function logDetail(action, detail) {
    console.log(action + " \"" + detail.processKey + "\"");
}
//# sourceMappingURL=plugin.js.map